import { jsx as _jsx, jsxs as _jsxs, Fragment as _Fragment } from "react/jsx-runtime";
import "./demo.css";
import { PlaybackOptions } from "./PlaybackOptions";
import { DEBUG_COMPONENT_ENABLED, PLAYERS } from "../constants";
import { useQueryParams } from "../hooks/useQueryParams";
import { HlsjsPlayer } from "./players/hlsjs/Hlsjs";
import { useCallback, useMemo, useRef, useState } from "react";
import { DownloadStatsChart } from "./chart/DownloadStatsChart";
import { NodeNetwork } from "./nodeNetwork/NodeNetwork";
import { DebugTools } from "./debugTools/DebugTools";
import { HlsjsDPlayer } from "./players/hlsjs/HlsjsDPLayer";
import { HlsjsClapprPlayer } from "./players/hlsjs/HlsjsClapprPlayer";
import { HlsjsPlyr } from "./players/hlsjs/HlsjsPlyr";
import { HlsjsOpenPlayer } from "./players/hlsjs/HlsjsOpenPlayer";
import { Shaka } from "./players/shaka/Shaka";
import { ShakaDPlayer } from "./players/shaka/ShakaDPlayer";
import { ShakaClappr } from "./players/shaka/ShakaClappr";
import { HlsjsMediaElement } from "./players/hlsjs/HlsjsMediaElement";
import { ShakaPlyr } from "./players/shaka/ShakaPlyr";
import { HlsjsVidstack } from "./players/hlsjs/HlsjsVidstack";
import { HlsjsVidstackIndexedDB } from "./players/hlsjs/HlsjsVidstackIndexedDB";
const playerComponents = {
    openPlayer_hls: HlsjsOpenPlayer,
    plyr_hls: HlsjsPlyr,
    clappr_hls: HlsjsClapprPlayer,
    dplayer_hls: HlsjsDPlayer,
    hlsjs_hls: HlsjsPlayer,
    vidstack_indexeddb_hls: HlsjsVidstackIndexedDB,
    shaka: Shaka,
    dplayer_shaka: ShakaDPlayer,
    clappr_shaka: ShakaClappr,
    mediaElement_hls: HlsjsMediaElement,
    plyr_shaka: ShakaPlyr,
    vidstack_hls: HlsjsVidstack,
};
export const P2PVideoDemo = ({ streamUrl, debugToolsEnabled = false, }) => {
    const data = useRef({
        httpDownloaded: 0,
        p2pDownloaded: 0,
        p2pUploaded: 0,
    });
    const { queryParams, setURLQueryParams } = useQueryParams(streamUrl);
    const trackers = useMemo(() => queryParams.trackers.split(","), [queryParams.trackers]);
    const [peers, setPeers] = useState([]);
    const onChunkDownloaded = useCallback((bytesLength, downloadSource) => {
        switch (downloadSource) {
            case "http":
                data.current.httpDownloaded += bytesLength;
                break;
            case "p2p":
                data.current.p2pDownloaded += bytesLength;
                break;
            default:
                break;
        }
    }, []);
    const onChunkUploaded = useCallback((bytesLength) => {
        data.current.p2pUploaded += bytesLength;
    }, []);
    const onPeerConnect = useCallback((params) => {
        if (params.streamType !== "main")
            return;
        setPeers((peers) => {
            return [...peers, params.peerId];
        });
    }, []);
    const onPeerClose = useCallback((params) => {
        if (params.streamType !== "main")
            return;
        setPeers((peers) => {
            return peers.filter((peer) => peer !== params.peerId);
        });
    }, []);
    const handlePlaybackOptionsUpdate = (url, player) => {
        if (!(player in PLAYERS))
            return;
        setURLQueryParams({ streamUrl: url, player });
    };
    const renderPlayer = () => {
        const PlayerComponent = playerComponents[queryParams.player];
        return PlayerComponent ? (_jsx(PlayerComponent, { streamUrl: queryParams.streamUrl, announceTrackers: trackers, swarmId: queryParams.swarmId === "" ? undefined : queryParams.swarmId, onPeerConnect: onPeerConnect, onPeerClose: onPeerClose, onChunkDownloaded: onChunkDownloaded, onChunkUploaded: onChunkUploaded })) : null;
    };
    const isDebugToolsEnabled = debugToolsEnabled || queryParams.debug === DEBUG_COMPONENT_ENABLED;
    return (_jsxs(_Fragment, { children: [_jsxs("div", { className: "demo-container", children: [_jsxs("div", { className: "column-1", children: [renderPlayer(), _jsx(DownloadStatsChart, { downloadStatsRef: data })] }), _jsxs("div", { className: "column-2", children: [_jsx("div", { style: { display: "flex" }, children: _jsx(PlaybackOptions, { updatePlaybackOptions: handlePlaybackOptionsUpdate, currentPlayer: queryParams.player, streamUrl: queryParams.streamUrl }) }), _jsx(NodeNetwork, { peers: peers }), trackers.length > 0 && (_jsxs("div", { className: "trackers-container", children: [_jsx("span", { children: "Trackers:" }), _jsx("ul", { className: "trackers-list", children: trackers.map((tracker) => (_jsx("li", { children: tracker }, tracker))) })] }))] })] }), isDebugToolsEnabled && _jsx(DebugTools, {})] }));
};
//# sourceMappingURL=P2PVideoDemo.js.map