import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { debug } from "p2p-media-loader-core";
import { useCallback, useEffect, useState } from "react";
export const DebugSelector = () => {
    const [activeLoggers, setActiveLoggers] = useLocalStorageItem("debug", [], loggersToStorageItem, storageItemToLoggers);
    const onChange = (event) => {
        setActiveLoggers(Array.from(event.target.selectedOptions, (option) => option.value));
    };
    return (_jsxs("div", { children: [_jsx("h4", { style: { marginBottom: 10, marginTop: 0 }, children: "Loggers: " }), _jsx("select", { value: activeLoggers, onChange: onChange, multiple: true, style: { width: 300, height: 200 }, children: loggers.map((logger) => (_jsx("option", { value: logger, children: logger }, logger))) })] }));
};
function useLocalStorageItem(prop, initValue, valueToStorageItem, storageItemToValue) {
    const [value, setValue] = useState(() => storageItemToValue(localStorage[prop]) ?? initValue);
    const setValueExternal = useCallback((value) => {
        setValue(value);
        if (typeof value === "function") {
            const prev = storageItemToValue(localStorage.getItem(prop));
            const next = value(prev);
            const result = valueToStorageItem(next);
            if (result !== null)
                localStorage.setItem(prop, result);
            else
                localStorage.removeItem(prop);
        }
        else {
            const result = valueToStorageItem(value);
            if (result !== null)
                localStorage.setItem(prop, result);
            else
                localStorage.removeItem(prop);
        }
    }, [prop, storageItemToValue, valueToStorageItem]);
    useEffect(() => {
        const eventHandler = (event) => {
            if (event.key !== prop)
                return;
            const value = event.newValue;
            setValue(storageItemToValue(value));
        };
        window.addEventListener("storage", eventHandler);
        return () => {
            window.removeEventListener("storage", eventHandler);
        };
    }, [prop, storageItemToValue]);
    return [value, setValueExternal];
}
const loggers = [
    "p2pml-core:hybrid-loader-main",
    "p2pml-core:hybrid-loader-secondary",
    "p2pml-core:p2p-tracker-client",
    "p2pml-core:peer",
    "p2pml-core:p2p-loaders-container",
    "p2pml-core:request-main",
    "p2pml-core:request-secondary",
    "p2pml-core:segment-memory-storage",
];
const loggersToStorageItem = (list) => {
    setTimeout(() => debug.enable(localStorage.debug), 0);
    if (list.length === 0)
        return null;
    return list.join(",");
};
const storageItemToLoggers = (storageItem) => {
    setTimeout(() => debug.enable(localStorage.debug), 0);
    if (!storageItem)
        return [];
    return storageItem.split(",");
};
//# sourceMappingURL=DebugSelector.js.map