import { jsx as _jsx } from "react/jsx-runtime";
import "./network.css";
import { useEffect, useRef, useState } from "react";
import { updateGraph, prepareGroups, createSimulation, } from "./network";
const DEFAULT_PEER_ID = "You";
const DEFAULT_NODE = { id: DEFAULT_PEER_ID, isMain: true };
const DEFAULT_GRAPH_DATA = {
    nodes: [DEFAULT_NODE],
    links: [],
};
export const NodeNetwork = ({ peers }) => {
    const svgRef = useRef(null);
    const svgContainerRef = useRef(null);
    const networkDataRef = useRef(DEFAULT_GRAPH_DATA);
    const simulationRef = useRef(null);
    const [svgDimensions, setSvgDimensions] = useState({
        width: 0,
        height: 0,
    });
    useEffect(() => {
        if (!svgRef.current)
            return;
        const handleResize = (entries) => {
            const entry = entries[0];
            const newDimensions = {
                width: entry.contentRect.width,
                height: entry.contentRect.width > 380 ? 250 : 400,
            };
            setSvgDimensions(newDimensions);
            simulationRef.current?.stop();
            simulationRef.current = createSimulation(newDimensions.width, newDimensions.height);
            updateGraph(networkDataRef.current.nodes, networkDataRef.current.links, simulationRef.current, svgRef.current);
        };
        prepareGroups(svgRef.current);
        const resizeObserver = new ResizeObserver(handleResize);
        if (svgContainerRef.current) {
            resizeObserver.observe(svgContainerRef.current);
        }
        return () => {
            resizeObserver.disconnect();
        };
    }, []);
    useEffect(() => {
        const allNodes = [
            ...peers.map((peerId) => ({ id: peerId, isMain: false })),
            DEFAULT_NODE,
        ];
        const allLinks = peers.map((peerId) => {
            const target = allNodes.find((n) => n.id === peerId);
            if (!target)
                throw new Error("Target node not found");
            return {
                source: DEFAULT_NODE,
                target,
                linkId: `${DEFAULT_PEER_ID}-${peerId}`,
            };
        });
        const networkData = networkDataRef.current;
        const nodesToAdd = allNodes.filter((an) => !networkData.nodes.find((n) => n.id === an.id));
        const nodesToRemove = networkData.nodes.filter((n) => !allNodes.find((an) => an.id === n.id));
        const linksToAdd = allLinks.filter((al) => !networkData.links.find((l) => l.linkId === al.linkId));
        const linksToRemove = networkData.links.filter((l) => !allLinks.find((al) => al.linkId === l.linkId));
        const updatedNodes = networkData.nodes.filter((n) => !nodesToRemove.find((rn) => rn.id === n.id));
        const updatedLinks = networkData.links.filter((l) => !linksToRemove.find((rl) => rl.linkId === l.linkId));
        const newNetworkData = {
            nodes: [...updatedNodes, ...nodesToAdd],
            links: [...updatedLinks, ...linksToAdd],
        };
        networkDataRef.current = newNetworkData;
        updateGraph(newNetworkData.nodes, newNetworkData.links, simulationRef.current, svgRef.current);
    }, [peers]);
    return (_jsx("div", { ref: svgContainerRef, className: "node-container", children: _jsx("svg", { className: "node-network", ref: svgRef, width: svgDimensions.width, height: svgDimensions.height }) }));
};
//# sourceMappingURL=NodeNetwork.js.map