import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import "./hlsjs.css";
import { useEffect, useRef } from "react";
import { subscribeToUiEvents } from "../utils";
import { HlsJsP2PEngine } from "p2p-media-loader-hlsjs";
import Hls from "hls.js";
export const HlsjsPlayer = ({ streamUrl, announceTrackers, swarmId, onPeerConnect, onPeerClose, onChunkDownloaded, onChunkUploaded, }) => {
    const videoRef = useRef(null);
    const qualityRef = useRef(null);
    useEffect(() => {
        if (!videoRef.current || !Hls.isSupported())
            return;
        const HlsWithP2P = HlsJsP2PEngine.injectMixin(Hls);
        const hls = new HlsWithP2P({
            p2p: {
                core: {
                    announceTrackers,
                    swarmId,
                },
                onHlsJsCreated(hls) {
                    subscribeToUiEvents({
                        engine: hls.p2pEngine,
                        onPeerConnect,
                        onPeerClose,
                        onChunkDownloaded,
                        onChunkUploaded,
                    });
                },
            },
        });
        hls.attachMedia(videoRef.current);
        hls.loadSource(streamUrl);
        hls.on(Hls.Events.MANIFEST_PARSED, () => {
            if (!qualityRef.current)
                return;
            updateQualityOptions(hls, qualityRef.current);
        });
        return () => hls.destroy();
    }, [
        onPeerConnect,
        onPeerClose,
        onChunkDownloaded,
        onChunkUploaded,
        streamUrl,
        announceTrackers,
        swarmId,
    ]);
    const updateQualityOptions = (hls, selectElement) => {
        if (hls.levels.length < 2) {
            selectElement.style.display = "none";
        }
        else {
            selectElement.style.display = "block";
            selectElement.options.length = 0;
            selectElement.add(new Option("Auto", "-1"));
            hls.levels.forEach((level, index) => {
                const label = `${level.height}p (${Math.round(level.bitrate / 1000)}k)`;
                selectElement.add(new Option(label, index.toString()));
            });
            selectElement.addEventListener("change", () => {
                hls.currentLevel = parseInt(selectElement.value);
            });
        }
    };
    return Hls.isSupported() ? (_jsxs("div", { className: "video-container", children: [_jsx("video", { ref: videoRef, style: { aspectRatio: "auto" }, controls: true, playsInline: true, autoPlay: true, muted: true }), _jsx("div", { className: "select-container", children: _jsx("select", { ref: qualityRef, className: "quality-selector" }) })] })) : (_jsx("div", { className: "error-message", children: _jsx("h3", { children: "HLS is not supported in this browser" }) }));
};
//# sourceMappingURL=Hlsjs.js.map