import { jsx as _jsx } from "react/jsx-runtime";
import "../clappr.css";
import { useEffect, useRef } from "react";
import { HlsJsP2PEngine } from "p2p-media-loader-hlsjs";
import { subscribeToUiEvents } from "../utils";
import Hls from "hls.js";
import { useScripts } from "../../../hooks/useScripts";
const SCRIPTS = [
    "https://cdn.jsdelivr.net/npm/@clappr/player@~0/dist/clappr.min.js",
    "https://cdn.jsdelivr.net/gh/clappr/clappr-level-selector-plugin@~0/dist/level-selector.min.js",
];
export const HlsjsClapprPlayer = ({ streamUrl, announceTrackers, swarmId, onPeerConnect, onPeerClose, onChunkDownloaded, onChunkUploaded, }) => {
    const areScriptsLoaded = useScripts(SCRIPTS);
    const containerRef = useRef(null);
    useEffect(() => {
        if (!containerRef.current || !areScriptsLoaded || !Hls.isSupported()) {
            return;
        }
        const engine = new HlsJsP2PEngine({
            core: {
                announceTrackers,
                swarmId,
            },
        });
        subscribeToUiEvents({
            engine,
            onPeerConnect,
            onPeerClose,
            onChunkDownloaded,
            onChunkUploaded,
        });
        /* eslint-disable  */
        // @ts-ignore
        const clapprPlayer = new Clappr.Player({
            parentId: `#${containerRef.current.id}`,
            source: streamUrl,
            mute: true,
            autoPlay: true,
            playback: {
                playInline: true,
                hlsjsConfig: {
                    ...engine.getConfigForHlsJs(),
                },
            },
            plugins: [window.LevelSelector],
            width: "100%",
            height: "100%",
        });
        engine.bindHls(() => clapprPlayer.core.getCurrentPlayback()?._hls);
        return () => {
            clapprPlayer.destroy();
            engine.destroy();
        };
        /* eslint-enable  */
    }, [
        areScriptsLoaded,
        announceTrackers,
        onChunkDownloaded,
        onChunkUploaded,
        onPeerConnect,
        onPeerClose,
        streamUrl,
        swarmId,
    ]);
    return Hls.isSupported() ? (_jsx("div", { ref: containerRef, id: "clappr-player" })) : (_jsx("div", { className: "error-message", children: _jsx("h3", { children: "HLS is not supported in this browser" }) }));
};
//# sourceMappingURL=HlsjsClapprPlayer.js.map