import { jsx as _jsx } from "react/jsx-runtime";
import { useEffect, useRef } from "react";
import DPlayer from "dplayer";
import { subscribeToUiEvents } from "../utils";
import { HlsJsP2PEngine } from "p2p-media-loader-hlsjs";
import Hls from "hls.js";
export const HlsjsDPlayer = ({ streamUrl, announceTrackers, swarmId, onPeerConnect, onPeerClose, onChunkDownloaded, onChunkUploaded, }) => {
    const containerRef = useRef(null);
    useEffect(() => {
        if (!Hls.isSupported())
            return;
        const HlsWithP2P = HlsJsP2PEngine.injectMixin(Hls);
        const hls = new HlsWithP2P({
            p2p: {
                core: {
                    announceTrackers,
                    swarmId,
                },
                onHlsJsCreated(hls) {
                    subscribeToUiEvents({
                        engine: hls.p2pEngine,
                        onPeerConnect,
                        onPeerClose,
                        onChunkDownloaded,
                        onChunkUploaded,
                    });
                },
            },
        });
        const player = new DPlayer({
            container: containerRef.current,
            video: {
                url: "",
                type: "customHls",
                customType: {
                    customHls: (video) => {
                        hls.attachMedia(video);
                        hls.loadSource(streamUrl);
                    },
                },
            },
        });
        player.play();
        return () => {
            player.destroy();
            hls.destroy();
        };
    }, [
        streamUrl,
        announceTrackers,
        onPeerConnect,
        onPeerClose,
        onChunkDownloaded,
        onChunkUploaded,
        swarmId,
    ]);
    return Hls.isSupported() ? (_jsx("div", { ref: containerRef, className: "video-container", children: _jsx("video", { playsInline: true, autoPlay: true, muted: true }) })) : (_jsx("div", { className: "error-message", children: _jsx("h3", { children: "HLS is not supported in this browser" }) }));
};
//# sourceMappingURL=HlsjsDPLayer.js.map