import { jsx as _jsx } from "react/jsx-runtime";
import "mediaelement";
import "mediaelement/build/mediaelementplayer.min.css";
import { useEffect, useRef, useState } from "react";
import Hls from "hls.js";
import { HlsJsP2PEngine } from "p2p-media-loader-hlsjs";
import { createVideoElements, subscribeToUiEvents } from "../utils";
export const HlsjsMediaElement = ({ streamUrl, announceTrackers, swarmId, onPeerConnect, onPeerClose, onChunkDownloaded, onChunkUploaded, }) => {
    const [isHlsSupported, setIsHlsSupported] = useState(true);
    const containerRef = useRef(null);
    /* eslint-disable  */
    // @ts-ignore
    useEffect(() => {
        if (!containerRef.current)
            return;
        if (!Hls.isSupported()) {
            setIsHlsSupported(false);
            return;
        }
        const { videoContainer, videoElement } = createVideoElements();
        containerRef.current.appendChild(videoContainer);
        window.Hls = HlsJsP2PEngine.injectMixin(Hls);
        // @ts-ignore
        const player = new MediaElementPlayer(videoElement.id, {
            iconSprite: "/mejs-controls.svg",
            videoHeight: "100%",
            hls: {
                p2p: {
                    onHlsJsCreated: (hls) => {
                        subscribeToUiEvents({
                            engine: hls.p2pEngine,
                            onPeerConnect,
                            onPeerClose,
                            onChunkDownloaded,
                            onChunkUploaded,
                        });
                    },
                    core: {
                        announceTrackers,
                        swarmId,
                    },
                },
            },
        });
        player.setSrc(streamUrl);
        player.load();
        return () => {
            window.Hls = undefined;
            player?.remove();
            videoContainer.remove();
        };
        /* eslint-enable  */
    }, [
        announceTrackers,
        onChunkDownloaded,
        onChunkUploaded,
        onPeerConnect,
        onPeerClose,
        streamUrl,
        swarmId,
    ]);
    return isHlsSupported ? (_jsx("div", { ref: containerRef })) : (_jsx("div", { className: "error-message", children: _jsx("h3", { children: "HLS is not supported in this browser" }) }));
};
//# sourceMappingURL=HlsjsMediaElement.js.map