import { jsx as _jsx } from "react/jsx-runtime";
import "openplayerjs/dist/openplayer.min.css";
import OpenPlayerJS from "openplayerjs";
import { useEffect, useRef } from "react";
import { HlsJsP2PEngine } from "p2p-media-loader-hlsjs";
import Hls from "hls.js";
import { createVideoElements, subscribeToUiEvents } from "../utils";
export const HlsjsOpenPlayer = ({ streamUrl, announceTrackers, swarmId, onPeerConnect, onPeerClose, onChunkDownloaded, onChunkUploaded, }) => {
    const playerContainerRef = useRef(null);
    useEffect(() => {
        if (!playerContainerRef.current || !Hls.isSupported())
            return;
        window.Hls = HlsJsP2PEngine.injectMixin(Hls);
        let isCleanedUp = false;
        let player;
        const { videoContainer, videoElement } = createVideoElements({
            videoClassName: "op-player__media",
        });
        playerContainerRef.current.appendChild(videoContainer);
        const cleanup = () => {
            isCleanedUp = true;
            player?.destroy();
            videoElement.remove();
            videoContainer.remove();
            window.Hls = undefined;
        };
        const initPlayer = async () => {
            const playerInit = new OpenPlayerJS(videoElement, {
                hls: {
                    p2p: {
                        onHlsJsCreated: (hls) => {
                            subscribeToUiEvents({
                                engine: hls.p2pEngine,
                                onPeerConnect,
                                onPeerClose,
                                onChunkDownloaded,
                                onChunkUploaded,
                            });
                        },
                        core: {
                            announceTrackers,
                            swarmId,
                        },
                    },
                },
                controls: {
                    layers: {
                        left: ["play", "time", "volume"],
                        right: ["settings", "fullscreen", "levels"],
                        middle: ["progress"],
                    },
                },
            });
            playerInit.src = [
                {
                    src: streamUrl,
                    type: "application/x-mpegURL",
                },
            ];
            try {
                await playerInit.init();
                player = playerInit;
            }
            catch (error) {
                player = playerInit;
                cleanup();
                // eslint-disable-next-line no-console
                console.error("Error initializing OpenPlayerJS", error);
            }
            if (isCleanedUp)
                cleanup();
        };
        void initPlayer();
        return () => cleanup();
    }, [
        announceTrackers,
        onChunkDownloaded,
        onChunkUploaded,
        onPeerConnect,
        onPeerClose,
        streamUrl,
        swarmId,
    ]);
    return Hls.isSupported() ? (_jsx("div", { ref: playerContainerRef, className: "player-container" })) : (_jsx("div", { className: "error-message", children: _jsx("h3", { children: "HLS is not supported in this browser" }) }));
};
//# sourceMappingURL=HlsjsOpenPlayer.js.map