import { jsx as _jsx } from "react/jsx-runtime";
import "plyr/dist/plyr.css";
import Plyr from "plyr";
import { useEffect, useRef } from "react";
import Hls from "hls.js";
import { HlsJsP2PEngine } from "p2p-media-loader-hlsjs";
import { createVideoElements, subscribeToUiEvents } from "../utils";
export const HlsjsPlyr = ({ streamUrl, announceTrackers, swarmId, onPeerConnect, onPeerClose, onChunkDownloaded, onChunkUploaded, }) => {
    const containerRef = useRef(null);
    useEffect(() => {
        if (!containerRef.current || !Hls.isSupported())
            return;
        let player;
        const { videoContainer, videoElement } = createVideoElements();
        containerRef.current.appendChild(videoContainer);
        const HlsWithP2P = HlsJsP2PEngine.injectMixin(Hls);
        const hls = new HlsWithP2P({
            p2p: {
                core: {
                    announceTrackers,
                    swarmId,
                },
                onHlsJsCreated(hls) {
                    subscribeToUiEvents({
                        engine: hls.p2pEngine,
                        onPeerConnect,
                        onPeerClose,
                        onChunkDownloaded,
                        onChunkUploaded,
                    });
                },
            },
        });
        hls.on(Hls.Events.MANIFEST_PARSED, () => {
            const { levels } = hls;
            const quality = {
                default: levels[levels.length - 1].height,
                options: levels.map((level) => level.height),
                forced: true,
                onChange: (newQuality) => {
                    levels.forEach((level, levelIndex) => {
                        if (level.height === newQuality) {
                            hls.currentLevel = levelIndex;
                        }
                    });
                },
            };
            player = new Plyr(videoElement, {
                quality,
                autoplay: true,
                muted: true,
            });
        });
        hls.attachMedia(videoElement);
        hls.loadSource(streamUrl);
        return () => {
            player?.destroy();
            videoContainer.remove();
            hls.destroy();
        };
    }, [
        announceTrackers,
        onChunkDownloaded,
        onChunkUploaded,
        onPeerConnect,
        onPeerClose,
        streamUrl,
        swarmId,
    ]);
    return Hls.isSupported() ? (_jsx("div", { ref: containerRef })) : (_jsx("div", { className: "error-message", children: _jsx("h3", { children: "HLS is not supported in this browser" }) }));
};
//# sourceMappingURL=HlsjsPlyr.js.map