import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import "./vidstack_indexed_db.css";
import "@vidstack/react/player/styles/default/theme.css";
import "@vidstack/react/player/styles/default/layouts/video.css";
import { MediaPlayer, MediaProvider, isHLSProvider, } from "@vidstack/react";
import { defaultLayoutIcons, DefaultVideoLayout, } from "@vidstack/react/player/layouts/default";
import { HlsJsP2PEngine } from "p2p-media-loader-hlsjs";
import { subscribeToUiEvents } from "../utils";
import { useCallback } from "react";
import Hls from "hls.js";
import { IndexedDbStorage } from "../../../custom-segment-storage-example/indexed-db-storage";
export const HlsjsVidstackIndexedDB = ({ streamUrl, announceTrackers, onPeerConnect, onPeerClose, onChunkDownloaded, onChunkUploaded, }) => {
    const onProviderChange = useCallback((provider) => {
        if (isHLSProvider(provider)) {
            const HlsWithP2P = HlsJsP2PEngine.injectMixin(Hls);
            provider.library = HlsWithP2P;
            const storageFactory = (_isLive) => new IndexedDbStorage();
            const config = {
                p2p: {
                    core: {
                        announceTrackers,
                        customSegmentStorageFactory: storageFactory,
                    },
                    onHlsJsCreated: (hls) => {
                        subscribeToUiEvents({
                            engine: hls.p2pEngine,
                            onPeerConnect,
                            onPeerClose,
                            onChunkDownloaded,
                            onChunkUploaded,
                        });
                    },
                },
            };
            provider.config = config;
        }
    }, [
        announceTrackers,
        onChunkDownloaded,
        onChunkUploaded,
        onPeerConnect,
        onPeerClose,
    ]);
    return (_jsxs("div", { className: "video-container", children: [_jsxs(MediaPlayer, { autoPlay: true, muted: true, onProviderChange: onProviderChange, src: streamUrl, playsInline: true, children: [_jsx(MediaProvider, {}), _jsx(DefaultVideoLayout, { icons: defaultLayoutIcons })] }), _jsx("div", { className: "notice", children: _jsxs("p", { children: [_jsx("strong", { children: "Note:" }), " Clearing of stored video segments is not implemented in this example. To remove cached segments, please clear your browser's IndexedDB manually.", " ", _jsx("a", { href: "https://github.com/Novage/p2p-media-loader/tree/main/packages/p2p-media-loader-demo/src/custom-segment-storage-example", target: "_blank", rel: "noreferrer", className: "source-code-link", children: "View Source Code" })] }) })] }));
};
//# sourceMappingURL=HlsjsVidstackIndexedDB.js.map