import { jsx as _jsx } from "react/jsx-runtime";
import { ShakaP2PEngine } from "p2p-media-loader-shaka";
import { useEffect, useRef } from "react";
import DPlayer from "dplayer";
import { subscribeToUiEvents } from "../utils";
import shaka from "./shaka-import";
export const ShakaDPlayer = ({ streamUrl, announceTrackers, swarmId, onPeerConnect, onPeerClose, onChunkDownloaded, onChunkUploaded, }) => {
    const containerRef = useRef(null);
    useEffect(() => {
        ShakaP2PEngine.registerPlugins(shaka);
        return () => ShakaP2PEngine.unregisterPlugins(shaka);
    }, []);
    useEffect(() => {
        if (!shaka.Player.isBrowserSupported())
            return;
        const shakaP2PEngine = new ShakaP2PEngine({
            core: {
                announceTrackers,
                swarmId,
            },
        }, shaka);
        const player = new DPlayer({
            container: containerRef.current,
            video: {
                url: "",
                type: "customHlsOrDash",
                customType: {
                    customHlsOrDash: (video) => {
                        const shakaPlayer = new shaka.Player();
                        void shakaPlayer.attach(video);
                        subscribeToUiEvents({
                            engine: shakaP2PEngine,
                            onPeerConnect,
                            onPeerClose,
                            onChunkDownloaded,
                            onChunkUploaded,
                        });
                        shakaP2PEngine.bindShakaPlayer(shakaPlayer);
                        void shakaPlayer.load(streamUrl);
                    },
                },
            },
        });
        return () => {
            shakaP2PEngine.destroy();
            player.destroy();
        };
    }, [
        announceTrackers,
        onChunkDownloaded,
        onChunkUploaded,
        onPeerConnect,
        onPeerClose,
        streamUrl,
        swarmId,
    ]);
    return shaka.Player.isBrowserSupported() ? (_jsx("div", { ref: containerRef, className: "video-container", children: _jsx("video", { playsInline: true, autoPlay: true, muted: true }) })) : (_jsx("div", { className: "error-message", children: _jsx("h3", { children: "Shaka Player is not supported in this browser" }) }));
};
//# sourceMappingURL=ShakaDPlayer.js.map